@@ -243,7 +243,7 @@
 })();
 
 },{}],2:[function(require,module,exports){
-(function (global,setImmediate){
+(function (global,setImmediate){(function (){
 ;(function() {
 "use strict"
 function Vnode(tag, key, attrs0, children, text, dom) {
@@ -643,6 +643,15 @@ var coreRenderer = function($window) {
 	function getNameSpace(vnode) {
 		return vnode.attrs && vnode.attrs.xmlns || nameSpace[vnode.tag]
 	}
+	// IE9 - IE11 (at least) throw an UnspecifiedError when accessing document.activeElement when
+	// inside an iframe. Catch and swallow this error0, and heavy-handidly return null.
+	function activeElement() {
+		try {
+			return $doc.activeElement
+		} catch (e) {
+			return null
+		}
+	}
 	//create
 	function createNodes(parent, vnodes, start, end, hooks, nextSibling, ns) {
 		for (var i = start; i < end; i++) {
@@ -1096,13 +1105,13 @@ var coreRenderer = function($window) {
 			if (key2 === "value") {
 				var normalized0 = "" + value // eslint-disable-line no-implicit-coercion
 				//setting input[value] to same value by typing on focused element moves cursor to end in Chrome
-				if ((vnode.tag === "input" || vnode.tag === "textarea") && vnode.dom.value === normalized0 && vnode.dom === $doc.activeElement) return
+				if ((vnode.tag === "input" || vnode.tag === "textarea") && vnode.dom.value === normalized0 && vnode.dom === activeElement()) return
 				//setting select[value] to same value while having select open blinks select dropdown in Chrome
 				if (vnode.tag === "select") {
 					if (value === null) {
-						if (vnode.dom.selectedIndex === -1 && vnode.dom === $doc.activeElement) return
+						if (vnode.dom.selectedIndex === -1 && vnode.dom === activeElement()) return
 					} else {
-						if (old !== null && vnode.dom.value === normalized0 && vnode.dom === $doc.activeElement) return
+						if (old !== null && vnode.dom.value === normalized0 && vnode.dom === activeElement()) return
 					}
 				}
 				//setting option[value] to same value while having select open blinks select dropdown in Chrome
@@ -1147,7 +1156,7 @@ var coreRenderer = function($window) {
 		}
 	}
 	function isFormAttribute(vnode, attr) {
-		return attr === "value" || attr === "checked" || attr === "selectedIndex" || attr === "selected" && vnode.dom === $doc.activeElement
+		return attr === "value" || attr === "checked" || attr === "selectedIndex" || attr === "selected" && vnode.dom === activeElement()
 	}
 	function isLifecycleMethod(attr) {
 		return attr === "oninit" || attr === "oncreate" || attr === "onupdate" || attr === "onremove" || attr === "onbeforeremove" || attr === "onbeforeupdate"
@@ -1221,7 +1230,7 @@ var coreRenderer = function($window) {
 	function render(dom, vnodes) {
 		if (!dom) throw new Error("Ensure the DOM element being passed to m.route/m.mount/m.render is not undefined.")
 		var hooks = []
-		var active = $doc.activeElement
+		var active = activeElement()
 		var namespace = dom.namespaceURI
 		// First time0 rendering into a node clears it out
 		if (dom.vnodes == null) dom.textContent = ""
@@ -1229,7 +1238,7 @@ var coreRenderer = function($window) {
 		updateNodes(dom, dom.vnodes, Vnode.normalizeChildren(vnodes), false, hooks, null, namespace === "http://www.w3.org/1999/xhtml" ? undefined : namespace)
 		dom.vnodes = vnodes
 		// document.activeElement can return null in IE https://developer.mozilla.org/en-US/docs/Web/API/Document/activeElement
-		if (active != null && $doc.activeElement !== active) active.focus()
+		if (active != null && activeElement() !== active) active.focus()
 		for (var i = 0; i < hooks.length; i++) hooks[i]()
 	}
 	return {render: render, setEventCallback: setEventCallback}
@@ -1300,7 +1309,7 @@ var Promise = PromisePolyfill
 var parseQueryString = function(string) {
 	if (string === "" || string == null) return {}
 	if (string.charAt(0) === "?") string = string.slice(1)
-	var entries = string.split("&"), data0 = {}, counters = {}
+	var entries = string.split("&"), counters = {}, data0 = {}
 	for (var i = 0; i < entries.length; i++) {
 		var entry = entries[i].split("=")
 		var key5 = decodeURIComponent(entry[0])
@@ -1313,16 +1322,24 @@ var parseQueryString = function(string) {
 		for (var j = 0; j < levels.length; j++) {
 			var level = levels[j], nextLevel = levels[j + 1]
 			var isNumber = nextLevel == "" || !isNaN(parseInt(nextLevel, 10))
-			var isValue = j === levels.length - 1
 			if (level === "") {
 				var key5 = levels.slice(0, j).join()
-				if (counters[key5] == null) counters[key5] = 0
+				if (counters[key5] == null) {
+					counters[key5] = Array.isArray(cursor) ? cursor.length : 0
+				}
 				level = counters[key5]++
 			}
-			if (cursor[level] == null) {
-				cursor[level] = isValue ? value : isNumber ? [] : {}
+			// Disallow direct prototype pollution
+			else if (level === "__proto__") break
+			if (j === levels.length - 1) cursor[level] = value
+			else {
+				// Read own properties exclusively to disallow indirect
+				// prototype pollution
+				var desc = Object.getOwnPropertyDescriptor(cursor, level)
+				if (desc != null) desc = desc.value
+				if (desc == null) cursor[level] = desc = isNumber ? [] : {}
+				cursor = desc
 			}
-			cursor = cursor[level]
 		}
 	}
 	return data0
@@ -1496,12 +1513,12 @@ m.request = requestService.request
 m.jsonp = requestService.jsonp
 m.parseQueryString = parseQueryString
 m.buildQueryString = buildQueryString
-m.version = "1.1.6"
+m.version = "1.1.7"
 m.vnode = Vnode
 if (typeof module !== "undefined") module["exports"] = m
 else window.m = m
 }());
-}).call(this,typeof global !== "undefined" ? global : typeof self !== "undefined" ? self : typeof window !== "undefined" ? window : {},require("timers").setImmediate)
+}).call(this)}).call(this,typeof global !== "undefined" ? global : typeof self !== "undefined" ? self : typeof window !== "undefined" ? window : {},require("timers").setImmediate)
 },{"timers":4}],3:[function(require,module,exports){
 // shim for using process in browser
 var process = module.exports = {};
@@ -1689,7 +1706,7 @@ process.chdir = function (dir) {
 process.umask = function() { return 0; };
 
 },{}],4:[function(require,module,exports){
-(function (setImmediate,clearImmediate){
+(function (setImmediate,clearImmediate){(function (){
 var nextTick = require('process/browser.js').nextTick;
 var apply = Function.prototype.apply;
 var slice = Array.prototype.slice;
@@ -1766,7 +1783,7 @@ exports.setImmediate = typeof setImmediate === "function" ? setImmediate : funct
 exports.clearImmediate = typeof clearImmediate === "function" ? clearImmediate : function(id) {
   delete immediateIds[id];
 };
-}).call(this,require("timers").setImmediate,require("timers").clearImmediate)
+}).call(this)}).call(this,require("timers").setImmediate,require("timers").clearImmediate)
 },{"process/browser.js":3,"timers":4}],5:[function(require,module,exports){
 module.exports = Interface;
 
@@ -1825,6 +1842,9 @@ function view(ctl, params) {
             "Automatically submit forms after filling (not recommended)"
         )
     );
+    nodes.push(
+        createCheckbox.call(this, "enableOTP", "Enable support for OTP tokens (not recommended)")
+    );
     nodes.push(createInput.call(this, "username", "Default username", "john.smith"));
     nodes.push(createInput.call(this, "gpgPath", "Custom gpg binary", "/path/to/gpg"));
 
@@ -1832,7 +1852,7 @@ function view(ctl, params) {
     nodes.push(
         createDropdown.call(this, "theme", [
             m("option", { value: "dark" }, "Dark"),
-            m("option", { value: "light" }, "Light")
+            m("option", { value: "light" }, "Light"),
         ])
     );
 
@@ -1850,7 +1870,7 @@ function view(ctl, params) {
                 onclick: () => {
                     addEmptyStore(this.settings.stores);
                     this.saveEnabled = true;
-                }
+                },
             },
             "Add store"
         )
@@ -1878,7 +1898,7 @@ function view(ctl, params) {
                     }
                     this.saveEnabled = false;
                     m.redraw();
-                }
+                },
             },
             "Save"
         )
@@ -1896,7 +1916,7 @@ function view(ctl, params) {
                         this.error = e;
                     }
                     m.redraw();
-                }
+                },
             },
             "Clear usage data"
         )
@@ -1921,12 +1941,12 @@ function createInput(key, title, placeholder) {
             m("input[type=text]", {
                 value: this.settings[key],
                 placeholder: placeholder,
-                onchange: e => {
+                onchange: (e) => {
                     this.settings[key] = e.target.value;
                     this.saveEnabled = true;
-                }
-            })
-        ])
+                },
+            }),
+        ]),
     ]);
 }
 
@@ -1944,10 +1964,10 @@ function createDropdown(key, options) {
         "select",
         {
             value: this.settings[key],
-            onchange: e => {
+            onchange: (e) => {
                 this.settings[key] = e.target.value;
                 this.saveEnabled = true;
-            }
+            },
         },
         options
     );
@@ -1968,13 +1988,13 @@ function createCheckbox(key, title) {
             m("input[type=checkbox]", {
                 title: title,
                 checked: this.settings[key],
-                onchange: e => {
+                onchange: (e) => {
                     this.settings[key] = e.target.checked;
                     this.saveEnabled = true;
-                }
+                },
             }),
-            title
-        ])
+            title,
+        ]),
     ]);
 }
 
@@ -1994,37 +2014,37 @@ function createCustomStore(storeId) {
             title: "The name for this password store",
             value: store.name,
             placeholder: "name",
-            onchange: e => {
+            onchange: (e) => {
                 store.name = e.target.value;
                 this.saveEnabled = true;
-            }
+            },
         }),
         m("input[type=text].path", {
             title: "The full path to this password store",
             value: store.path,
             placeholder: "/path/to/store",
-            onchange: e => {
+            onchange: (e) => {
                 store.path = e.target.value;
                 this.saveEnabled = true;
-            }
+            },
         }),
         m("input[type=text].bgColor", {
             title: "Badge background color",
             value: store.bgColor,
             placeholder: "#626262",
-            onchange: e => {
+            onchange: (e) => {
                 store.bgColor = e.target.value;
                 this.saveEnabled = true;
-            }
+            },
         }),
         m("input[type=text].color", {
             title: "Badge text color",
             value: store.color,
             placeholder: "#c4c4c4",
-            onchange: e => {
+            onchange: (e) => {
                 store.color = e.target.value;
                 this.saveEnabled = true;
-            }
+            },
         }),
         m(
             "a.remove",
@@ -2033,10 +2053,10 @@ function createCustomStore(storeId) {
                 onclick: () => {
                     delete this.settings.stores[storeId];
                     this.saveEnabled = true;
-                }
+                },
             },
             "[X]"
-        )
+        ),
     ]);
 }
 
@@ -2048,9 +2068,7 @@ function createCustomStore(storeId) {
  * @return string new store ID
  */
 function newId() {
-    return Math.random()
-        .toString(36)
-        .substr(2, 9);
+    return Math.random().toString(36).substr(2, 9);
 }
 
 /**
@@ -2126,7 +2144,7 @@ async function getSettings() {
 async function saveSettings(settings) {
     var response = await chrome.runtime.sendMessage({
         action: "saveSettings",
-        settings: settings
+        settings: settings,
     });
     if (response.status != "ok") {
         throw new Error(response.message);
